<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_MODULE'] = [
    [
        'version' => 'FROM_VERSION',
        'library' => 'MODULE/migrations/MODULE_upgrade_FROM_VERSION',
    ],
];
